/*
 *  (C) Copyright 2009 Wojtek Kaniewski <wojtekka@irc.pl>
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License Version
 *  2.1 as published by the Free Software Foundation.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public
 *  License along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307,
 *  USA.
 */

#ifndef LIBGADU_DEBUG_H
#define LIBGADU_DEBUG_H

#include "libgadu.h"

const char *gg_debug_state(enum gg_state_t state);
const char *gg_debug_event(enum gg_event_t event);
void gg_debug_dump(struct gg_session *sess, int level, const char *buf, size_t len);
void gg_debug_common(struct gg_session *sess, int level, const char *format, va_list ap);

#endif /* LIBGADU_DEBUG_H */
